@@ -2,12 +2,13 @@ use strict;
 use warnings;
 
 package Template::Resolver;
-$Template::Resolver::VERSION = '1.03';
+$Template::Resolver::VERSION = '1.04';
 # ABSTRACT: A powerful, and simple, library for resolving placeholders in templated files
 # PODNAME: Template::Resolver
 
 use Carp;
 use Log::Any;
+use Scalar::Util qw(blessed);
 use Template::Transformer;
 
 my $logger = Log::Any->get_logger();
@@ -22,7 +23,7 @@ sub _entity_to_properties {
     $properties = {} unless $properties;
 
     my $ref = ref($entity);
-    if ( $ref && $ref eq 'HASH' ) {
+    if ( ( $ref && $ref eq 'HASH' ) || blessed($entity) ) {
         foreach my $key ( keys( %{$entity} ) ) {
             _entity_to_properties( $entity->{$key}, $properties,
                 ( $prefix ? "$prefix.$key" : $key ) );
@@ -102,7 +103,7 @@ Template::Resolver - A powerful, and simple, library for resolving placeholders
 
 =head1 VERSION
 
-version 1.03
+version 1.04
 
 =head1 SYNOPSIS
 
